pub struct SdmmcHostInfoResponse {
pub info: SdmmcHostInfo,
}Fields
info: SdmmcHostInfoTrait Implementations
Sourceimpl Clone for SdmmcHostInfoResponse
impl Clone for SdmmcHostInfoResponse
Sourcefn clone(&self) -> SdmmcHostInfoResponse
fn clone(&self) -> SdmmcHostInfoResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SdmmcHostInfoResponse
impl Debug for SdmmcHostInfoResponse
Sourceimpl<'a, ___E> Encode<SdmmcHostInfoResponse, ___E> for &'a SdmmcHostInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SdmmcHostInfoResponse, ___E> for &'a SdmmcHostInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcHostInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcHostInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SdmmcHostInfoResponse, ___E> for SdmmcHostInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SdmmcHostInfoResponse, ___E> for SdmmcHostInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcHostInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcHostInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SdmmcHostInfoResponse>, ___E> for &'a SdmmcHostInfoResponse
impl<'a, ___E> EncodeOption<Box<'static, SdmmcHostInfoResponse>, ___E> for &'a SdmmcHostInfoResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SdmmcHostInfoResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SdmmcHostInfoResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SdmmcHostInfoResponse>, ___E> for SdmmcHostInfoResponse
impl<___E> EncodeOption<Box<'static, SdmmcHostInfoResponse>, ___E> for SdmmcHostInfoResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SdmmcHostInfoResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SdmmcHostInfoResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SdmmcHostInfoResponse> for SdmmcHostInfoResponse
impl FromWire<SdmmcHostInfoResponse> for SdmmcHostInfoResponse
Sourcefn from_wire(wire: SdmmcHostInfoResponse) -> Self
fn from_wire(wire: SdmmcHostInfoResponse) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SdmmcHostInfoResponse> for SdmmcHostInfoResponse
impl FromWireRef<SdmmcHostInfoResponse> for SdmmcHostInfoResponse
Sourcefn from_wire_ref(wire: &SdmmcHostInfoResponse) -> Self
fn from_wire_ref(wire: &SdmmcHostInfoResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for SdmmcHostInfoResponse
impl Hash for SdmmcHostInfoResponse
Sourceimpl Ord for SdmmcHostInfoResponse
impl Ord for SdmmcHostInfoResponse
Sourcefn cmp(&self, other: &SdmmcHostInfoResponse) -> Ordering
fn cmp(&self, other: &SdmmcHostInfoResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SdmmcHostInfoResponse
impl PartialEq for SdmmcHostInfoResponse
Sourceimpl PartialOrd for SdmmcHostInfoResponse
impl PartialOrd for SdmmcHostInfoResponse
impl Copy for SdmmcHostInfoResponse
impl Eq for SdmmcHostInfoResponse
impl StructuralPartialEq for SdmmcHostInfoResponse