#[repr(C)]pub struct SdmmcRequestResponse {
pub response: [u32; 4],
}Fields
response: [u32; 4]Trait Implementations
Sourceimpl Clone for SdmmcRequestResponse
impl Clone for SdmmcRequestResponse
Sourcefn clone(&self) -> SdmmcRequestResponse
fn clone(&self) -> SdmmcRequestResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SdmmcRequestResponse
impl Debug for SdmmcRequestResponse
Sourceimpl<'a, ___E> Encode<SdmmcRequestResponse, ___E> for &'a SdmmcRequestResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SdmmcRequestResponse, ___E> for &'a SdmmcRequestResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcRequestResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcRequestResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SdmmcRequestResponse, ___E> for SdmmcRequestResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SdmmcRequestResponse, ___E> for SdmmcRequestResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SdmmcRequestResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, SdmmcRequestResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcRequestResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcRequestResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SdmmcRequestResponse>, ___E> for &'a SdmmcRequestResponse
impl<'a, ___E> EncodeOption<Box<'static, SdmmcRequestResponse>, ___E> for &'a SdmmcRequestResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SdmmcRequestResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SdmmcRequestResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SdmmcRequestResponse>, ___E> for SdmmcRequestResponse
impl<___E> EncodeOption<Box<'static, SdmmcRequestResponse>, ___E> for SdmmcRequestResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SdmmcRequestResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SdmmcRequestResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SdmmcRequestResponse> for SdmmcRequestResponse
impl FromWire<SdmmcRequestResponse> for SdmmcRequestResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SdmmcRequestResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<SdmmcRequestResponse, Self>
Sourcefn from_wire(wire: SdmmcRequestResponse) -> Self
fn from_wire(wire: SdmmcRequestResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<SdmmcRequestResponse> for SdmmcRequestResponse
impl FromWireRef<SdmmcRequestResponse> for SdmmcRequestResponse
Sourcefn from_wire_ref(wire: &SdmmcRequestResponse) -> Self
fn from_wire_ref(wire: &SdmmcRequestResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for SdmmcRequestResponse
impl Hash for SdmmcRequestResponse
Sourceimpl Ord for SdmmcRequestResponse
impl Ord for SdmmcRequestResponse
Sourcefn cmp(&self, other: &SdmmcRequestResponse) -> Ordering
fn cmp(&self, other: &SdmmcRequestResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SdmmcRequestResponse
impl PartialEq for SdmmcRequestResponse
Sourceimpl PartialOrd for SdmmcRequestResponse
impl PartialOrd for SdmmcRequestResponse
impl Copy for SdmmcRequestResponse
impl Eq for SdmmcRequestResponse
impl StructuralPartialEq for SdmmcRequestResponse