#[repr(C)]pub struct SdmmcSetBusWidthRequest {
pub bus_width: SdmmcBusWidth,
}Fields
bus_width: SdmmcBusWidthTrait Implementations
Sourceimpl Clone for SdmmcSetBusWidthRequest
impl Clone for SdmmcSetBusWidthRequest
Sourcefn clone(&self) -> SdmmcSetBusWidthRequest
fn clone(&self) -> SdmmcSetBusWidthRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SdmmcSetBusWidthRequest
impl Debug for SdmmcSetBusWidthRequest
Sourceimpl<'a, ___E> Encode<SdmmcSetBusWidthRequest, ___E> for &'a SdmmcSetBusWidthRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SdmmcSetBusWidthRequest, ___E> for &'a SdmmcSetBusWidthRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcSetBusWidthRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcSetBusWidthRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SdmmcSetBusWidthRequest, ___E> for SdmmcSetBusWidthRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SdmmcSetBusWidthRequest, ___E> for SdmmcSetBusWidthRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SdmmcSetBusWidthRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, SdmmcSetBusWidthRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcSetBusWidthRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcSetBusWidthRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SdmmcSetBusWidthRequest>, ___E> for &'a SdmmcSetBusWidthRequest
impl<'a, ___E> EncodeOption<Box<'static, SdmmcSetBusWidthRequest>, ___E> for &'a SdmmcSetBusWidthRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SdmmcSetBusWidthRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SdmmcSetBusWidthRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SdmmcSetBusWidthRequest>, ___E> for SdmmcSetBusWidthRequest
impl<___E> EncodeOption<Box<'static, SdmmcSetBusWidthRequest>, ___E> for SdmmcSetBusWidthRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SdmmcSetBusWidthRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SdmmcSetBusWidthRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SdmmcSetBusWidthRequest> for SdmmcSetBusWidthRequest
impl FromWire<SdmmcSetBusWidthRequest> for SdmmcSetBusWidthRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SdmmcSetBusWidthRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<SdmmcSetBusWidthRequest, Self>
Sourcefn from_wire(wire: SdmmcSetBusWidthRequest) -> Self
fn from_wire(wire: SdmmcSetBusWidthRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<SdmmcSetBusWidthRequest> for SdmmcSetBusWidthRequest
impl FromWireRef<SdmmcSetBusWidthRequest> for SdmmcSetBusWidthRequest
Sourcefn from_wire_ref(wire: &SdmmcSetBusWidthRequest) -> Self
fn from_wire_ref(wire: &SdmmcSetBusWidthRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for SdmmcSetBusWidthRequest
impl Hash for SdmmcSetBusWidthRequest
Sourceimpl Ord for SdmmcSetBusWidthRequest
impl Ord for SdmmcSetBusWidthRequest
Sourcefn cmp(&self, other: &SdmmcSetBusWidthRequest) -> Ordering
fn cmp(&self, other: &SdmmcSetBusWidthRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SdmmcSetBusWidthRequest
impl PartialEq for SdmmcSetBusWidthRequest
Sourceimpl PartialOrd for SdmmcSetBusWidthRequest
impl PartialOrd for SdmmcSetBusWidthRequest
impl Copy for SdmmcSetBusWidthRequest
impl Eq for SdmmcSetBusWidthRequest
impl StructuralPartialEq for SdmmcSetBusWidthRequest