pub struct SdmmcUnregisterVmoRequest {
pub vmo_id: u32,
pub client_id: u8,
}Fields
vmo_id: u32client_id: u8Trait Implementations
Sourceimpl Clone for SdmmcUnregisterVmoRequest
impl Clone for SdmmcUnregisterVmoRequest
Sourcefn clone(&self) -> SdmmcUnregisterVmoRequest
fn clone(&self) -> SdmmcUnregisterVmoRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SdmmcUnregisterVmoRequest
impl Debug for SdmmcUnregisterVmoRequest
Sourceimpl<'a, ___E> Encode<SdmmcUnregisterVmoRequest, ___E> for &'a SdmmcUnregisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SdmmcUnregisterVmoRequest, ___E> for &'a SdmmcUnregisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcUnregisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcUnregisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SdmmcUnregisterVmoRequest, ___E> for SdmmcUnregisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SdmmcUnregisterVmoRequest, ___E> for SdmmcUnregisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcUnregisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcUnregisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SdmmcUnregisterVmoRequest>, ___E> for &'a SdmmcUnregisterVmoRequestwhere
___E: Encoder + ?Sized,
&'a SdmmcUnregisterVmoRequest: Encode<SdmmcUnregisterVmoRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, SdmmcUnregisterVmoRequest>, ___E> for &'a SdmmcUnregisterVmoRequestwhere
___E: Encoder + ?Sized,
&'a SdmmcUnregisterVmoRequest: Encode<SdmmcUnregisterVmoRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SdmmcUnregisterVmoRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SdmmcUnregisterVmoRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SdmmcUnregisterVmoRequest>, ___E> for SdmmcUnregisterVmoRequest
impl<___E> EncodeOption<Box<'static, SdmmcUnregisterVmoRequest>, ___E> for SdmmcUnregisterVmoRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SdmmcUnregisterVmoRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SdmmcUnregisterVmoRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<SdmmcUnregisterVmoRequest> for SdmmcUnregisterVmoRequest
impl FromWire<SdmmcUnregisterVmoRequest> for SdmmcUnregisterVmoRequest
Sourcefn from_wire(wire: SdmmcUnregisterVmoRequest) -> Self
fn from_wire(wire: SdmmcUnregisterVmoRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SdmmcUnregisterVmoRequest> for SdmmcUnregisterVmoRequest
impl FromWireRef<SdmmcUnregisterVmoRequest> for SdmmcUnregisterVmoRequest
Sourcefn from_wire_ref(wire: &SdmmcUnregisterVmoRequest) -> Self
fn from_wire_ref(wire: &SdmmcUnregisterVmoRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for SdmmcUnregisterVmoRequest
impl Hash for SdmmcUnregisterVmoRequest
Sourceimpl Ord for SdmmcUnregisterVmoRequest
impl Ord for SdmmcUnregisterVmoRequest
Sourcefn cmp(&self, other: &SdmmcUnregisterVmoRequest) -> Ordering
fn cmp(&self, other: &SdmmcUnregisterVmoRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for SdmmcUnregisterVmoRequest
impl PartialOrd for SdmmcUnregisterVmoRequest
impl Copy for SdmmcUnregisterVmoRequest
impl Eq for SdmmcUnregisterVmoRequest
impl StructuralPartialEq for SdmmcUnregisterVmoRequest