#[repr(C)]pub struct SdmmcHostInfoResponse {
pub info: SdmmcHostInfo,
}Expand description
The wire type corresponding to SdmmcHostInfoResponse.
Fields
info: SdmmcHostInfoTrait Implementations
Sourceimpl Clone for SdmmcHostInfoResponse
impl Clone for SdmmcHostInfoResponse
Sourcefn clone(&self) -> SdmmcHostInfoResponse
fn clone(&self) -> SdmmcHostInfoResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SdmmcHostInfoResponse
impl Constrained for SdmmcHostInfoResponse
Sourceimpl Debug for SdmmcHostInfoResponse
impl Debug for SdmmcHostInfoResponse
Sourceimpl<___D> Decode<___D> for SdmmcHostInfoResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SdmmcHostInfoResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<SdmmcHostInfoResponse, ___E> for &'a SdmmcHostInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SdmmcHostInfoResponse, ___E> for &'a SdmmcHostInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcHostInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcHostInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SdmmcHostInfoResponse, ___E> for SdmmcHostInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SdmmcHostInfoResponse, ___E> for SdmmcHostInfoResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcHostInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcHostInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<SdmmcHostInfoResponse, ___E> for SdmmcHostInfoResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<SdmmcHostInfo, ___E>,
impl<___E, T0> Encode<SdmmcHostInfoResponse, ___E> for SdmmcHostInfoResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<SdmmcHostInfo, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcHostInfoResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcHostInfoResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SdmmcHostInfoResponse> for SdmmcHostInfoResponse
impl FromWire<SdmmcHostInfoResponse> for SdmmcHostInfoResponse
Sourcefn from_wire(wire: SdmmcHostInfoResponse) -> Self
fn from_wire(wire: SdmmcHostInfoResponse) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SdmmcHostInfoResponse> for SdmmcHostInfoResponse
impl FromWireRef<SdmmcHostInfoResponse> for SdmmcHostInfoResponse
Sourcefn from_wire_ref(wire: &SdmmcHostInfoResponse) -> Self
fn from_wire_ref(wire: &SdmmcHostInfoResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for SdmmcHostInfoResponse
impl IntoNatural for SdmmcHostInfoResponse
Sourcetype Natural = SdmmcHostInfoResponse
type Natural = SdmmcHostInfoResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SdmmcHostInfoResponse
impl Wire for SdmmcHostInfoResponse
Sourcetype Narrowed<'de> = SdmmcHostInfoResponse
type Narrowed<'de> = SdmmcHostInfoResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.