#[repr(C)]pub struct SdmmcSetBusWidthRequest {
pub bus_width: SdmmcBusWidth,
}Expand description
The wire type corresponding to SdmmcSetBusWidthRequest.
Fields
bus_width: SdmmcBusWidthTrait Implementations
Sourceimpl Clone for SdmmcSetBusWidthRequest
impl Clone for SdmmcSetBusWidthRequest
Sourcefn clone(&self) -> SdmmcSetBusWidthRequest
fn clone(&self) -> SdmmcSetBusWidthRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SdmmcSetBusWidthRequest
impl Constrained for SdmmcSetBusWidthRequest
Sourceimpl Debug for SdmmcSetBusWidthRequest
impl Debug for SdmmcSetBusWidthRequest
Sourceimpl<___D> Decode<___D> for SdmmcSetBusWidthRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SdmmcSetBusWidthRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<SdmmcSetBusWidthRequest, ___E> for &'a SdmmcSetBusWidthRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SdmmcSetBusWidthRequest, ___E> for &'a SdmmcSetBusWidthRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcSetBusWidthRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcSetBusWidthRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SdmmcSetBusWidthRequest, ___E> for SdmmcSetBusWidthRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SdmmcSetBusWidthRequest, ___E> for SdmmcSetBusWidthRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SdmmcSetBusWidthRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, SdmmcSetBusWidthRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcSetBusWidthRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcSetBusWidthRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<SdmmcSetBusWidthRequest, ___E> for SdmmcSetBusWidthRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<SdmmcBusWidth, ___E>,
impl<___E, T0> Encode<SdmmcSetBusWidthRequest, ___E> for SdmmcSetBusWidthRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<SdmmcBusWidth, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcSetBusWidthRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcSetBusWidthRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SdmmcSetBusWidthRequest> for SdmmcSetBusWidthRequest
impl FromWire<SdmmcSetBusWidthRequest> for SdmmcSetBusWidthRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SdmmcSetBusWidthRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<SdmmcSetBusWidthRequest, Self>
Sourcefn from_wire(wire: SdmmcSetBusWidthRequest) -> Self
fn from_wire(wire: SdmmcSetBusWidthRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<SdmmcSetBusWidthRequest> for SdmmcSetBusWidthRequest
impl FromWireRef<SdmmcSetBusWidthRequest> for SdmmcSetBusWidthRequest
Sourcefn from_wire_ref(wire: &SdmmcSetBusWidthRequest) -> Self
fn from_wire_ref(wire: &SdmmcSetBusWidthRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for SdmmcSetBusWidthRequest
impl IntoNatural for SdmmcSetBusWidthRequest
Sourcetype Natural = SdmmcSetBusWidthRequest
type Natural = SdmmcSetBusWidthRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SdmmcSetBusWidthRequest
impl Wire for SdmmcSetBusWidthRequest
Sourcetype Narrowed<'de> = SdmmcSetBusWidthRequest
type Narrowed<'de> = SdmmcSetBusWidthRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.