#[repr(C)]pub struct SdmmcUnregisterVmoRequest {
pub vmo_id: Uint32,
pub client_id: u8,
}Expand description
The wire type corresponding to SdmmcUnregisterVmoRequest.
Fields
vmo_id: Uint32client_id: u8Trait Implementations
Sourceimpl Clone for SdmmcUnregisterVmoRequest
impl Clone for SdmmcUnregisterVmoRequest
Sourcefn clone(&self) -> SdmmcUnregisterVmoRequest
fn clone(&self) -> SdmmcUnregisterVmoRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SdmmcUnregisterVmoRequest
impl Constrained for SdmmcUnregisterVmoRequest
Sourceimpl Debug for SdmmcUnregisterVmoRequest
impl Debug for SdmmcUnregisterVmoRequest
Sourceimpl<___D> Decode<___D> for SdmmcUnregisterVmoRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SdmmcUnregisterVmoRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<SdmmcUnregisterVmoRequest, ___E> for &'a SdmmcUnregisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SdmmcUnregisterVmoRequest, ___E> for &'a SdmmcUnregisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcUnregisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcUnregisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SdmmcUnregisterVmoRequest, ___E> for SdmmcUnregisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SdmmcUnregisterVmoRequest, ___E> for SdmmcUnregisterVmoRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcUnregisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcUnregisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<SdmmcUnregisterVmoRequest, ___E> for SdmmcUnregisterVmoRequest<T0, T1>
impl<___E, T0, T1> Encode<SdmmcUnregisterVmoRequest, ___E> for SdmmcUnregisterVmoRequest<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SdmmcUnregisterVmoRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SdmmcUnregisterVmoRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SdmmcUnregisterVmoRequest> for SdmmcUnregisterVmoRequest
impl FromWire<SdmmcUnregisterVmoRequest> for SdmmcUnregisterVmoRequest
Sourcefn from_wire(wire: SdmmcUnregisterVmoRequest) -> Self
fn from_wire(wire: SdmmcUnregisterVmoRequest) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<SdmmcUnregisterVmoRequest> for SdmmcUnregisterVmoRequest
impl FromWireRef<SdmmcUnregisterVmoRequest> for SdmmcUnregisterVmoRequest
Sourcefn from_wire_ref(wire: &SdmmcUnregisterVmoRequest) -> Self
fn from_wire_ref(wire: &SdmmcUnregisterVmoRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for SdmmcUnregisterVmoRequest
impl IntoNatural for SdmmcUnregisterVmoRequest
Sourcetype Natural = SdmmcUnregisterVmoRequest
type Natural = SdmmcUnregisterVmoRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SdmmcUnregisterVmoRequest
impl Wire for SdmmcUnregisterVmoRequest
Sourcetype Narrowed<'de> = SdmmcUnregisterVmoRequest
type Narrowed<'de> = SdmmcUnregisterVmoRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.